@@ -3,13 +3,14 @@ import uuid
 
 import django
 from allauth.account.models import EmailAddress
+from django.conf import settings
 from django.contrib.auth.models import AbstractUser as BaseUser
 from django.contrib.auth.models import UserManager as BaseUserManager
 from django.core.cache import cache
 from django.core.exceptions import ValidationError
 from django.db import models
 from django.utils.functional import cached_property
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from phonenumber_field.modelfields import PhoneNumberField
 from swapper import load_model
 
@@ -51,8 +52,19 @@ class AbstractUser(BaseUser):
     bio = models.TextField(_('bio'), blank=True)
     url = models.URLField(_('URL'), blank=True)
     company = models.CharField(_('company'), max_length=30, blank=True)
-    location = models.CharField(_('location'), max_length=128, blank=True)
-    phone_number = PhoneNumberField(unique=True, blank=True, null=True)
+    location = models.CharField(_('location'), max_length=256, blank=True)
+    phone_number = PhoneNumberField(
+        _('phone number'), unique=True, blank=True, null=True
+    )
+    birth_date = models.DateField(_('birth date'), blank=True, null=True)
+    notes = models.TextField(
+        _('notes'), help_text=_('notes for internal usage'), blank=True
+    )
+    language = models.CharField(
+        max_length=8,
+        choices=settings.LANGUAGES,
+        default=settings.LANGUAGE_CODE,
+    )
 
     objects = UserManager()
 
@@ -62,7 +74,7 @@ class AbstractUser(BaseUser):
 
     @staticmethod
     def _get_pk(obj):
-        """ meant for internal usage only """
+        """meant for internal usage only"""
         if isinstance(obj, (uuid.UUID, str)):
             pk = obj
         elif isinstance(obj, BaseOrganization):
@@ -139,25 +151,15 @@ class AbstractUser(BaseUser):
             self.email = None
         if self.phone_number == '':
             self.phone_number = None
-
-    @property
-    def permissions(self):
-        """
-        Returns the user permissions from the cache, if the cache is
-        empty it will call self.get_all_permissions() and cache the result
-        """
-        cache_key = f'user_{self.pk}_permissions'
-        permissions = cache.get(cache_key)
-        if permissions is not None:
-            return permissions
-        permissions = self.get_all_permissions()
-        cache.set(cache_key, permissions)
-        return permissions
-
-    def has_permission(self, permission):
-        if self.is_superuser:
-            return True
-        return permission in self.permissions
+        if (
+            self.email
+            and self._meta.model.objects.filter(email__iexact=self.email)
+            .exclude(pk=self.pk)
+            .exists()
+        ):
+            raise ValidationError(
+                {'email': _('User with this Email address already exists.')}
+            )
 
 
 # on django 3.1, the max length of first_name has been changed, we need to
